@@ -1,17 +1,18 @@
-import io
+import importlib
 import os
 import pathlib
-import warnings
 from dataclasses import dataclass
 
-import numpy as np
 import pytest
 import yaml
 
 # Avoid all imports of asdf at this level in order to avoid circular imports
+HAS_NEW_PLUGIN = importlib.util.find_spec("pytest_asdf_plugin") is not None
 
 
 def pytest_addoption(parser):
+    if HAS_NEW_PLUGIN:
+        return
     parser.addini("asdf_schema_root", "Root path indicating where schemas are stored")
     parser.addini("asdf_schema_skip_names", "Base names of files to skip in schema tests")
     parser.addini(
@@ -41,12 +42,6 @@ def pytest_addoption(parser):
         type="bool",
         default=False,
     )
-    parser.addini(
-        "asdf_schema_ignore_version_mismatch",
-        "Set to true to disable warnings when missing explicit support for a tag",
-        type="string",
-        default="",
-    )
     parser.addoption("--asdf-tests", action="store_true", help="Enable ASDF schema tests")
 
 
@@ -206,43 +201,17 @@ class AsdfSchemaExampleItem(pytest.Item):
         return result
 
     def runtest(self):
-        from asdf import AsdfFile, _block, generic_io
-        from asdf.testing import helpers
+        import asdf
+        from asdf.testing.helpers import yaml_to_asdf
 
-        # Make sure that the examples in the schema files (and thus the
-        # ASDF standard document) are valid.
-        buff = helpers.yaml_to_asdf("example: " + self.example.example.strip(), version=self.example.version)
+        # warn inside test, we don't do this yet to allow time for downstream packages to adopt pytest-asdf-plugin
+        # warnings.warn("pytest_asdf is deprecated, install pytest_asdf_plugin instead", DeprecationWarning)
 
-        ff = AsdfFile(
-            uri=pathlib.Path(self.filename).expanduser().absolute().as_uri(),
-            ignore_unrecognized_tag=self.ignore_unrecognized_tag,
-        )
-
-        # Fake an external file
-        ff2 = AsdfFile({"data": np.empty((1024 * 1024 * 8), dtype=np.uint8)})
-
-        ff._external_asdf_by_uri[
-            (pathlib.Path(self.filename).expanduser().absolute().parent / "external.asdf").as_uri()
-        ] = ff2
-
-        wb = _block.writer.WriteBlock(np.zeros(1024 * 1024 * 8, dtype=np.uint8))
-        with generic_io.get_file(buff, mode="rw") as f:
-            f.seek(0, 2)
-            _block.writer.write_blocks(f, [wb, wb], streamed_block=wb)
-            f.seek(0)
-
-        try:
-            ff._open_impl(ff, buff, mode="rw")
-        except Exception:
-            print(f"Example: {self.example.description}\n From file: {self.filename}")
-            raise
-
-        # Just test we can write it out.  A roundtrip test
-        # wouldn't always yield the correct result, so those have
-        # to be covered by "real" unit tests.
-        if b"external.asdf" not in buff.getvalue():
-            buff = io.BytesIO()
-            ff.write_to(buff)
+        # check the example is valid
+        buff = yaml_to_asdf("example: " + self.example.example.strip(), version=self.example.version)
+        tagged_tree = asdf.util.load_yaml(buff, tagged=True)
+        instance = asdf.AsdfFile(version=self.example.version)
+        asdf.schema.validate(tagged_tree, instance, reading=True)
 
     def reportinfo(self):
         return self.fspath, 0, ""
@@ -271,6 +240,8 @@ def _parse_test_list(content):
 
 
 def pytest_collect_file(file_path, parent):
+    if HAS_NEW_PLUGIN:
+        return None
     if not (parent.config.getini("asdf_schema_tests_enabled") or parent.config.getoption("asdf_tests")):
         return None
 
@@ -282,14 +253,6 @@ def pytest_collect_file(file_path, parent):
     skip_examples = parent.config.getini("asdf_schema_skip_examples")
     validate_default = parent.config.getini("asdf_schema_validate_default")
     ignore_unrecognized_tag = parent.config.getini("asdf_schema_ignore_unrecognized_tag")
-    ignore_version_mismatch = parent.config.getini("asdf_schema_ignore_version_mismatch")
-    if ignore_version_mismatch != "":
-        from asdf.exceptions import AsdfDeprecationWarning
-
-        warnings.warn(
-            "asdf_schema_ignore_version_mismatch is deprecated and has done nothing since asdf 3.0.0",
-            AsdfDeprecationWarning,
-        )
 
     skip_tests = _parse_test_list(parent.config.getini("asdf_schema_skip_tests"))
     xfail_tests = _parse_test_list(parent.config.getini("asdf_schema_xfail_tests"))
